<?php
/*
Plugin Name: WP Google Analytics Events Pro
Plugin URI: http://wpgoogleanalyticsevents.com
Description: Adds the Google Analytics code to your website and enables you to send events on scroll or click.
Version: 1.1
Author: Yuval Oren
Author URI: http://wpgoogleanalyticsevents.com
License: GPLv2
*/

/* Copyright 2013 Yuval Oren (email : yuval@steam.io)
This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
*/



/*
 * Plugin Activation
 */

require_once("include/functions.php");

register_activation_hook( __FILE__, 'ga_events_install' );

// this is the URL our updater / license checker pings. This should be the URL of the site with EDD installed
define( 'EDD_SL_STORE_URL', 'http://wpgoogleanalyticsevents.com' ); // IMPORTANT: change the name of this constant to something unique to prevent conflicts with other plugins using this system

// the name of your product. This is the title of your product in EDD and should match the download title in EDD exactly
define( 'EDD_SL_ITEM_NAME', 'WP Google Analytics Events Pro' ); // IMPORTANT: change the name of this constant to something unique to prevent conflicts with other plugins using this system

if( !class_exists( 'EDD_SL_Plugin_Updater' ) ) {
    // load our custom updater if it doesn't already exist
    include( dirname( __FILE__ ) . '/EDD_SL_Plugin_Updater.php' );
}

$options = get_option('ga_events_options');
// retrieve our license key from the DB
$license_key = trim( $options['license'] );

// setup the updater
$edd_updater = new EDD_SL_Plugin_Updater( EDD_SL_STORE_URL, __FILE__, array(
        'version' 	=> '1.1', 		// current version number
        'license' 	=> $license_key, 	// license key (used get_option above to retrieve from DB)
        'item_name'     => EDD_SL_ITEM_NAME, 	// name of this plugin
        'author' 	=> 'Yuval Oren'  // author of this plugin
    )
);

function ga_events_install() {
    $ga_events_options = array(
        'id' => '',
        'license' => '',
        'status' => '',
        'disable_admin' => '0',
        'link_clicks_delay' => '0',
        'divs' => array(array(id => '',type =>'', action => '', cat => '', label => '', bounce => '')),
        'click' => array(array(id => '',type =>'', action => '', cat => '', label => '', bounce => ''))
    );
    update_option( 'ga_events_options', $ga_events_options );

}

/*
 * Plugin Admin Settings
 */

add_action( 'admin_menu', 'ga_events_menu');

function ga_events_menu() {
    add_options_page('WP Google Analytics Settings','WP Google Analytics Events Pro','manage_options', __FILE__, 'ga_events_settings_page' );
}

function ga_events_settings_page() {
?>
    <div class="wrap">
        <?php screen_icon( 'plugins' ); ?>
    <h2>WP Google Analytics Events Pro</h2>

        <form method="post" action='options.php'>
            <?php settings_fields('ga_events_options'); ?>
            <?php do_settings_sections('ga_events'); ?>
            <input class="button-primary" type="submit" name="submit" value="Save Changes" />
        </form>

    </div>

<?php
}
//add_action('admin_init', 'edd_activate_license');

add_action('admin_init', 'ga_events_admin_init');

function ga_events_admin_init() {
    register_setting('ga_events_options','ga_events_options','ga_events_validate');
    add_settings_section('ga_events_main','WP Google Analytics Events Pro Settings', 'ga_events_section_text','ga_events');
    add_settings_field('ga_events_license', 'License Key','ga_events_license_input','ga_events','ga_events_main');
    add_settings_field('ga_events_id', 'Google Analytics Identifier','ga_events_setting_input','ga_events','ga_events_main');
    add_settings_field('ga_events_admin', 'Disable Google Analytics for admin users','ga_events_setting_admin_input','ga_events','ga_events_main');
    add_settings_field('ga_events_link_click', 'Add delay to link clicks','ga_events_setting_link_click_delay_input','ga_events','ga_events_main');
    add_settings_field('ga_events_divs', 'Scroll Events','ga_events_setting_divs_input','ga_events','ga_events_main');
    add_settings_field('ga_events_click', 'Click Events','ga_events_setting_click_input','ga_events','ga_events_main');




}

function ga_events_section_text() {
    echo "<span></span><a href='http://wpgoogleanalyticsevents.com/documentation/'>Need Help?</a></span><span style='margin-left:8px;'><a href='https://support.zoho.com/portal/steamio/HomePage.do'>Support</a></span>";
    echo "<p>Enter your settings</p>";
}

function ga_events_license_input() {
    $options = get_option('ga_events_options');
    $license = $options['license'];
    $status = $options['status'];
    echo "<input id='license' name='ga_events_options[license]' type='text' value='$license' />";

    if( false != $license ) {
        if( $status !== false && $status == 'valid' ) {
            echo '<span style="color:green;">'._e('active'),'</span>';
        }else {
           echo '<input type="submit" class="button-secondary" name="edd_license_activate" value="Activate License")/>';
        }
    }
}

function ga_events_setting_input() {
    $options = get_option('ga_events_options');
    $id = $options['id'];
    echo "<input id='id' name='ga_events_options[id]' type='text' value='$id' />";

}

function ga_events_setting_admin_input() {
    $options = get_option('ga_events_options');
    $id = $options['disable_admin'];
    echo "<input id='disable_admin' name='ga_events_options[disable_admin]' type='checkbox' value='1' " . checked( $id , 1,false) . " />";

}

function ga_events_setting_link_click_delay_input() {
    $options = get_option('ga_events_options');
    $id = $options['link_clicks_delay'];
    echo "<input id='link_clicks_delay' name='ga_events_options[link_clicks_delay]' type='text' value='$id' SIZE='4' /> ms";

}

function ga_events_setting_divs_input() {
    $options = get_option('ga_events_options');
    $divs = $options['divs'];
    printSettingsTable($divs,'divs');
}



function ga_events_setting_click_input() {
    $options = get_option('ga_events_options');
    $click = $options['click'];
    printSettingsTable($click,'click');


    echo "<script>
            jQuery('.remove').click(function (event) {
                event.preventDefault();
                jQuery(this).closest('tr').remove();
            });
            jQuery('.add').click(function (event) {
                event.preventDefault();
            });
          </script>
    ";

}

function edd_activate_license() {


}


function ga_events_validate($form){
    $updated = array();
    $updated['id'] = $form['id'];
    $updated['disable_admin'] = $form['disable_admin'];
    $updated['link_clicks_delay'] = $form['link_clicks_delay'];
    $updated['license'] = $form['license'];
    $options =  get_option( 'ga_events_options' );
    $updated['status'] = $options['status'];
    $old = $options['license'];

    if( $old && $old !=  $updated['license'] ) {
        $updated['status'] = '';
    }



    // listen for our activate button to be clicked
    if( isset( $_POST['edd_license_activate'] ) ) {

        // retrieve the license from the database
        $options = get_option('ga_events_options');
        $license = trim( $options['license'] );


        // data to send in our API request
        $api_params = array(
            'edd_action'=> 'activate_license',
            'license'   => $license,
            'item_name' => urlencode( 'WP Google Analytics Events Pro' ) // the name of our product in EDD
        );

        // Call the custom API.
        $response = wp_remote_get( add_query_arg( $api_params, EDD_SL_STORE_URL ) );

        // make sure the response came back okay
        if ( is_wp_error( $response ) )
            return false;

        // decode the license data
        $license_data = json_decode( wp_remote_retrieve_body( $response ) );
        $updated['status'] = $license_data->license;

    }


    for ($i = 0, $j = 0; $i< sizeof($form['divs']); $i++){
        if ($form['divs'][$i][0]){
            $updated['divs'][$j] = $form['divs'][$i];
            $j++;
        }
    }

    for ($i = 0, $j = 0; $i< sizeof($form['click']); $i++){
        if ($form['click'][$i][0]){
            $updated['click'][$j] = $form['click'][$i];
            $j++;
        }
    }

    return $updated;
}


/*
 * Init
 */

add_action('init','ga_events_scripts');

function ga_events_scripts() {
    wp_enqueue_script('jquery');
    wp_enqueue_script('scrolldepth',plugins_url( '/js/ga-scroll-events.js' , __FILE__ ));
}


add_action( 'plugins_loaded', 'ga_events_setup');

function ga_events_setup() {
    add_action( 'wp_head', 'ga_events_header', 100 );
}


add_action( 'wp_footer', 'ga_events_footer', 100 );


add_shortcode('scrollevent','ga_events_short_scroll');
add_shortcode('clickevent','ga_events_short_click');

function ga_events_short_scroll($attr, $content) {
    $cat = isset($attr['cat'])? $attr['cat'] : 'Default Category';
    $action = isset($attr['action'])? $attr['action'] : 'Default Action';
    $label = isset($attr['label'])? $attr['label'] : 'Default Label';
    $bounce = isset($attr['bounce'])? $attr['bounce'] : 'false';

    if(!empty($content)){
        $new_content = add_class_to_element($content,'scrollevent',$cat,$action,$label, $bounce);
        return $new_content;
    }
}

function ga_events_short_click($attr, $content){
    $cat = isset($attr['cat'])? $attr['cat'] : 'Default Category';
    $action = isset($attr['action'])? $attr['action'] : 'Default Action';
    $label = isset($attr['label'])? $attr['label'] : 'Default Label';
    $bounce = isset($attr['bounce'])? $attr['bounce'] : 'false';



    if(!empty($content)){
        $new_content = add_class_to_element($content,'clickevent',$cat,$action,$label, $bounce);
        return $new_content;
    }
}

?>